.. _related-projects-page:

==================
 Related Projects
==================

PyCpuSimulator
--------------

`PyCpuSimulator <https://github.com/FabriceSalvaire/PyCpuSimulator>`_ is CPU simulator written in Python featuring:

* Micro-Code Language to describe instruction
* Opcode Decoder using Decision Tree
* Read HEX firmware format
* AVR Core CPU simulation is ongoing

Ahkab
-----

`Ahkab <https://ahkab.github.io/ahkab>`_ is a SPICE-like electronic circuit simulator written in Python.

Lcapy
-----

`Lcapy <http://lcapy.elec.canterbury.ac.nz>`_ is a Python package for linear circuit analysis. Lcapy
uses `SymPy <http://www.sympy.org>`_ for symbolic analysis.

Lcapy can semi-automate the drawing of schematics from a netlist using Circuitikz.

Lcapy sources are available at https://github.com/mph-/lcapy

Other Projects
--------------

 * `eispice <http://www.thedigitalmachine.net/eispice.html>`_
 * `SPICE OPUS <http://www.spiceopus.si>`_ and `PyOPUS <http://fides.fe.uni-lj.si/pyopus>`_
 * `A Python interface for SPICE-based simulations <http://ieeexplore.ieee.org/xpl/login.jsp?tp=&arnumber=5595224&url=http%3A%2F%2Fieeexplore.ieee.org%2Fxpls%2Fabs_all.jsp%3Farnumber%3D5595224>`_
